==> playgroundtools-1.3.1.tar.gz: playgroundtools-1.3.1/CHANGELOG.md <==
# Change Log

## Version 1.3.1
- Update README
- Fix config read issue
- Minor status bug fix

## Version 1.3.0
- Add verbosity to CLI
- Add status management for the CLI and GUI
- Additional improvements to the private code

## Version 1.2.0
- Add a GUI for managing playgrounds.

## Version 1.1.1
- Fix `about` and `version` strings.

## Version 1.1.0
- Add the ability to edit configuration from the CLI
- Refine the code

## Version 1.0.3
- Fix links to `config.json` in the README
- Add additional content.

## Version 1.0.2
- Change `MANIFEST.in` to include `config.json`.

## Version 1.0.1
- Initial published release.

## Version 1.0.0
- Initial built release.

## Version 0.11.0
- Clean up the project by simplifying code.

## Version 0.10.0
- Add documentation to the README
- Split command testing into individual tests
- Edit `build` workflow.

## Version 0.9.0
- Add a changelog
- Add some metadata to the README.

## Version 0.8.0
- Make corrections to the setup file to fix metadata issues.

## Version 0.7.0
- Set up basic tests
- Configure `black`, `flake8`, and `isort`.

## Version 0.6.0
- Make the filesystem easier to work with.

## Version 0.5.0
- Change references to `Scripts/*` to also include `bin/*`

## Version 0.4.0
- Add basic exception handlers throughout the code.

## Version 0.3.0
- Add functions for the individual commands
- Fix the dispatch to the `delete` function.

## Version 0.2.0
- Add a basic command parser
- Add a config file for the package.

## Version 0.1.0
- Implement the basic package file structure.

==> playgroundtools-1.7.1.tar.gz: playgroundtools-1.7.1/CHANGELOG.md <==
# Change Log

## Version 1.7.1
- Fix `config delete` command on README

## Version 1.7.0
- Add ability to delete config keys
- Reduce complexity of cleaning config
- Simplify status management
- Add additional config tests

## Version 1.6.0
- Add `lib` field to GUI
- Add ability to modify module and args at playground runtime
- Add example to README
- Fix invalid config error for `new`

## Version 1.5.1
- Fix README `config` commands
- Fix README JSON example
- Fix `config add` with no value specified

## Version 1.5.0
- Add additional tests to check for exceptions
- Edit test workflow
- Simplify test fixtures

## Version 1.4.0
- Add ability to read from custom config files
- Add more config tests
- Simplify config functions
- Simplify config exceptions
- Fix config key read bug
- Fix `load_file_resource` path issue

## Version 1.3.1
- Update README
- Fix config read issue
- Minor status bug fix

## Version 1.3.0
- Add verbosity to CLI
- Add status management for the CLI and GUI
- Additional improvements to the private code

## Version 1.2.0
- Add a GUI for managing playgrounds.

## Version 1.1.1
- Fix `about` and `version` strings.

## Version 1.1.0
- Add the ability to edit configuration from the CLI
- Refine the code

## Version 1.0.3
- Fix links to `config.json` in the README
- Add additional content.

## Version 1.0.2
- Change `MANIFEST.in` to include `config.json`.

## Version 1.0.1
- Initial published release.

## Version 1.0.0
- Initial built release.

## Version 0.11.0
- Clean up the project by simplifying code.

## Version 0.10.0
- Add documentation to the README
- Split command testing into individual tests
- Edit `build` workflow.

## Version 0.9.0
- Add a changelog
- Add some metadata to the README.

## Version 0.8.0
- Make corrections to the setup file to fix metadata issues.

## Version 0.7.0
- Set up basic tests
- Configure `black`, `flake8`, and `isort`.

## Version 0.6.0
- Make the filesystem easier to work with.

## Version 0.5.0
- Change references to `Scripts/*` to also include `bin/*`

## Version 0.4.0
- Add basic exception handlers throughout the code.

## Version 0.3.0
- Add functions for the individual commands
- Fix the dispatch to the `delete` function.

## Version 0.2.0
- Add a basic command parser
- Add a config file for the package.

## Version 0.1.0
- Implement the basic package file structure.
